[![PyPI version](https://badge.fury.io/py/sconce-scms.svg)](https://badge.fury.io/py/sconce-scms)

# SCONCE-SCMS
## Spherical and Conic Cosmic Web with Extended SCMS Algorithms


* Free software: MIT license
* Documentation: https://sconce-scms.readthedocs.io.


Installation
--------

To install the latest version of ```sconce-scms``` from this repository, run:

```
python setup.py install
```

To pip install a stable release, run:
```
pip install sconce-scms
```

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
